<?php

/**
 * @file
 * EHoverScroll.php
 *
 * Yii extension implementing the jQuery HoverScroll plugin.
 * @link http://rascarlito.free.fr/hoverscroll/
 *
 * @author Matt Kelliher
 * @license FREE BEER LICENSE VERSION 1.02
 * @version 1.0
 */

class EHoverScroll extends CWidget
{
  /**
   * @var array
   * The items to display.
   * Each element must include an HTML attribute,
   * as well as height and width (in pixels).
   *
   * $items = array(
   *   array(
   *     'height' => '50',
   *     'width'  => '80',
   *     'html'   => '<img src="/path/to/image" alt="Example" />',
   *   ),
   * );
   */
  public $items = array();

  /**
   * @var array
   * Parameters defining the shape and behavior of the list.
   */
  public $options = array(
    'vertical'      => FALSE, // Display the list vertically or horizontally
    'width'         => 400,   // Width of the list container
    'height'        => 50,    // Height of the list container
    'arrows'        => TRUE,  // Display direction indicator arrows or not
    'arrowsOpacity' => 0.7,   // Max possible opacity of the arrows
    'fixedArrows'   => FALSE, // Fixed arrows on the sides of the list (disables arrowsOpacity)
    'rtl'           => FALSE, // Print images from right to left
    'debug'         => FALSE, // Debug output in the firebug console
  );

  /**
   * @var integer the counter for generating implicit IDs.
   */
  private static $_hsCounter = 0;

  /**
   * @var string id of the widget.
   */
  private $_id;

  /**
   * Returns the ID of the widget or generates a new one if requested.
   * @param boolean $autoGenerate whether to generate an ID if it is not set previously
   * @return string id of the widget.
   */
  public function getId($autoGenerate = TRUE)
  {
    if ($this->_id !== NULL)
      return $this->_id;
    else if ($autoGenerate)
      return $this->_id = 'hoverScroll'. self::$_hsCounter++;
  }


  /**
   * Initializes the widget.
   */
  public function init()
  {
    if (!empty($this->items)) {
      $assets = Yii::app()->assetManager->publish(dirname(__FILE__) . DIRECTORY_SEPARATOR . 'assets');

      $clientScript = Yii::app()->clientScript;
      $clientScript->registerCoreScript('jquery');
      $clientScript->registerScriptFile($assets .'/jquery.hoverscroll.js');
      $clientScript->registerCssFile($assets .'/jquery.hoverscroll.css');

      $options = CJavaScript::encode($this->options);
      $js = "jQuery('#$this->id').hoverscroll($options);";
      $clientScript->registerScript(__CLASS__ .'#'. $this->id, $js);
    }

    parent::init();
  }

  
  /**
   * Executes the widget.
   */
  public function run()
  {
    if (!empty($this->items)) {
      echo CHtml::openTag('ul', array('id' => $this->id));

      // Render items
      foreach ($this->items as $item) {
        if (isset($item['height'], $item['width'], $item['html'])) {
          $style = 'width: '. $item['width'] .'px;';
          $style .= ' height: '. $item['height'] .'px;';

          echo CHtml::tag('li', array('style' => $style), $item['html']);
        }
      }

      echo CHtml::closeTag('ul');
    }
  }

}
